@@ -37,6 +37,27 @@ class EdgeFunction(
     See https://docs.aws.amazon.com/cdk/latest/guide/bootstrapping.html or 'cdk bootstrap --help' for options.
 
     :resource: AWS::Lambda::Function
+
+    Example::
+
+        # my_bucket is of type Bucket
+        # A Lambda@Edge function added to default behavior of a Distribution
+        # and triggered on every request
+        my_func = cloudfront.experimental.EdgeFunction(self, "MyFunction",
+            runtime=lambda_.Runtime.NODEJS_12_X,
+            handler="index.handler",
+            code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler"))
+        )
+        cloudfront.Distribution(self, "myDist",
+            default_behavior=cloudfront.BehaviorOptions(
+                origin=origins.S3Origin(my_bucket),
+                edge_lambdas=[cloudfront.EdgeLambda(
+                    function_version=my_func.current_version,
+                    event_type=cloudfront.LambdaEdgeEventType.VIEWER_REQUEST
+                )
+                ]
+            )
+        )
     '''
 
     def __init__(
@@ -280,9 +301,9 @@ class EdgeFunction(
         self,
         id: builtins.str,
         *,
-        principal: aws_cdk.aws_iam.IPrincipal,
         action: typing.Optional[builtins.str] = None,
         event_source_token: typing.Optional[builtins.str] = None,
+        principal: aws_cdk.aws_iam.IPrincipal,
         scope: typing.Optional[aws_cdk.core.Construct] = None,
         source_account: typing.Optional[builtins.str] = None,
         source_arn: typing.Optional[builtins.str] = None,
@@ -290,17 +311,17 @@ class EdgeFunction(
         '''Adds a permission to the Lambda resource policy.
 
         :param id: -
-        :param principal: The entity for which you are granting permission to invoke the Lambda function. This entity can be any valid AWS service principal, such as s3.amazonaws.com or sns.amazonaws.com, or, if you are granting cross-account permission, an AWS account ID. For example, you might want to allow a custom application in another AWS account to push events to Lambda by invoking your function. The principal can be either an AccountPrincipal or a ServicePrincipal.
         :param action: The Lambda actions that you want to allow in this statement. For example, you can specify lambda:CreateFunction to specify a certain action, or use a wildcard (``lambda:*``) to grant permission to all Lambda actions. For a list of actions, see Actions and Condition Context Keys for AWS Lambda in the IAM User Guide. Default: 'lambda:InvokeFunction'
         :param event_source_token: A unique token that must be supplied by the principal invoking the function. Default: The caller would not need to present a token.
+        :param principal: The entity for which you are granting permission to invoke the Lambda function. This entity can be any valid AWS service principal, such as s3.amazonaws.com or sns.amazonaws.com, or, if you are granting cross-account permission, an AWS account ID. For example, you might want to allow a custom application in another AWS account to push events to Lambda by invoking your function. The principal can be either an AccountPrincipal or a ServicePrincipal.
         :param scope: The scope to which the permission constructs be attached. The default is the Lambda function construct itself, but this would need to be different in cases such as cross-stack references where the Permissions would need to sit closer to the consumer of this permission (i.e., the caller). Default: - The instance of lambda.IFunction
         :param source_account: The AWS account ID (without hyphens) of the source owner. For example, if you specify an S3 bucket in the SourceArn property, this value is the bucket owner's account ID. You can use this property to ensure that all source principals are owned by a specific account.
         :param source_arn: The ARN of a resource that is invoking your function. When granting Amazon Simple Storage Service (Amazon S3) permission to invoke your function, specify this property with the bucket ARN as its value. This ensures that events generated only from the specified bucket, not just any bucket from any AWS account that creates a mapping to your function, can invoke the function.
         '''
         permission = aws_cdk.aws_lambda.Permission(
-            principal=principal,
             action=action,
             event_source_token=event_source_token,
+            principal=principal,
             scope=scope,
             source_account=source_account,
             source_arn=source_arn,
@@ -790,6 +811,27 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         :param handler: The name of the method within your code that Lambda calls to execute your function. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-features.html#gettingstarted-features-programmingmodel. Use ``Handler.FROM_IMAGE`` when defining a function from a Docker image. NOTE: If you specify your source code as inline text by specifying the ZipFile property within the Code property, specify index.function_name as the handler.
         :param runtime: The runtime environment for the Lambda function that you are uploading. For valid values, see the Runtime property in the AWS Lambda Developer Guide. Use ``Runtime.FROM_IMAGE`` when when defining a function from a Docker image.
         :param stack_id: The stack ID of Lambda@Edge function. Default: - ``edge-lambda-stack-${region}``
+
+        Example::
+
+            # my_bucket is of type Bucket
+            # A Lambda@Edge function added to default behavior of a Distribution
+            # and triggered on every request
+            my_func = cloudfront.experimental.EdgeFunction(self, "MyFunction",
+                runtime=lambda_.Runtime.NODEJS_12_X,
+                handler="index.handler",
+                code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler"))
+            )
+            cloudfront.Distribution(self, "myDist",
+                default_behavior=cloudfront.BehaviorOptions(
+                    origin=origins.S3Origin(my_bucket),
+                    edge_lambdas=[cloudfront.EdgeLambda(
+                        function_version=my_func.current_version,
+                        event_type=cloudfront.LambdaEdgeEventType.VIEWER_REQUEST
+                    )
+                    ]
+                )
+            )
         '''
         if isinstance(current_version_options, dict):
             current_version_options = aws_cdk.aws_lambda.VersionOptions(**current_version_options)
